"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListServicesByNamespace = void 0;
const ListServicesByNamespaceCommand_1 = require("../commands/ListServicesByNamespaceCommand");
const ECSClient_1 = require("../ECSClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListServicesByNamespaceCommand_1.ListServicesByNamespaceCommand(input), ...args);
};
async function* paginateListServicesByNamespace(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof ECSClient_1.ECSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ECS | ECSClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListServicesByNamespace = paginateListServicesByNamespace;
