import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { GetAccountSummaryResponse } from "../models/models_0";
/**
 * The input for {@link GetAccountSummaryCommand}.
 */
export interface GetAccountSummaryCommandInput {
}
/**
 * The output of {@link GetAccountSummaryCommand}.
 */
export interface GetAccountSummaryCommandOutput extends GetAccountSummaryResponse, __MetadataBearer {
}
/**
 * <p>Retrieves information about IAM entity usage and IAM quotas in the Amazon Web Services
 *             account.</p>
 *          <p> For information about IAM quotas, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html">IAM and STS quotas</a> in the
 *                 <i>IAM User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, GetAccountSummaryCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, GetAccountSummaryCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const command = new GetAccountSummaryCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetAccountSummaryCommandInput} for command's `input` shape.
 * @see {@link GetAccountSummaryCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or
 *       failure.</p>
 *
 *
 * @example To get information about IAM entity quotas and usage in the current account
 * ```javascript
 * // The following command returns information about the IAM entity quotas and usage in the current AWS account.
 * const input = undefined;
 * const command = new GetAccountSummaryCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "SummaryMap": {
 *     "AccessKeysPerUserQuota": 2,
 *     "AccountAccessKeysPresent": 1,
 *     "AccountMFAEnabled": 0,
 *     "AccountSigningCertificatesPresent": 0,
 *     "AttachedPoliciesPerGroupQuota": 10,
 *     "AttachedPoliciesPerRoleQuota": 10,
 *     "AttachedPoliciesPerUserQuota": 10,
 *     "GlobalEndpointTokenVersion": 2,
 *     "GroupPolicySizeQuota": 5120,
 *     "Groups": 15,
 *     "GroupsPerUserQuota": 10,
 *     "GroupsQuota": 100,
 *     "MFADevices": 6,
 *     "MFADevicesInUse": 3,
 *     "Policies": 8,
 *     "PoliciesQuota": 1000,
 *     "PolicySizeQuota": 5120,
 *     "PolicyVersionsInUse": 22,
 *     "PolicyVersionsInUseQuota": 10000,
 *     "ServerCertificates": 1,
 *     "ServerCertificatesQuota": 20,
 *     "SigningCertificatesPerUserQuota": 2,
 *     "UserPolicySizeQuota": 2048,
 *     "Users": 27,
 *     "UsersQuota": 5000,
 *     "VersionsPerPolicyQuota": 5
 *   }
 * }
 * *\/
 * // example id: 9d8447af-f344-45de-8219-2cebc3cce7f2
 * ```
 *
 */
export declare class GetAccountSummaryCommand extends $Command<GetAccountSummaryCommandInput, GetAccountSummaryCommandOutput, IAMClientResolvedConfig> {
    readonly input: GetAccountSummaryCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: GetAccountSummaryCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: IAMClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetAccountSummaryCommandInput, GetAccountSummaryCommandOutput>;
    private serialize;
    private deserialize;
}
