/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { diag } from '@opentelemetry/api';
import { SemanticResourceAttributes } from '@opentelemetry/semantic-conventions';
import { Resource } from '../Resource';
/**
 * ProcessDetectorSync will be used to detect the resources related current process running
 * and being instrumented from the NodeJS Process module.
 */
var ProcessDetectorSync = /** @class */ (function () {
    function ProcessDetectorSync() {
    }
    ProcessDetectorSync.prototype.detect = function (config) {
        var _a;
        // Skip if not in Node.js environment.
        if (typeof process !== 'object') {
            return Resource.empty();
        }
        var processResource = (_a = {},
            _a[SemanticResourceAttributes.PROCESS_PID] = process.pid,
            _a[SemanticResourceAttributes.PROCESS_EXECUTABLE_NAME] = process.title || '',
            _a[SemanticResourceAttributes.PROCESS_COMMAND] = process.argv[1] || '',
            _a[SemanticResourceAttributes.PROCESS_COMMAND_LINE] = process.argv.join(' ') || '',
            _a[SemanticResourceAttributes.PROCESS_RUNTIME_VERSION] = process.versions.node,
            _a[SemanticResourceAttributes.PROCESS_RUNTIME_NAME] = 'nodejs',
            _a[SemanticResourceAttributes.PROCESS_RUNTIME_DESCRIPTION] = 'Node.js',
            _a);
        return this._getResourceAttributes(processResource, config);
    };
    /**
     * Validates process resource attribute map from process variables
     *
     * @param processResource The unsantized resource attributes from process as key/value pairs.
     * @param config: Config
     * @returns The sanitized resource attributes.
     */
    ProcessDetectorSync.prototype._getResourceAttributes = function (processResource, _config) {
        if (processResource[SemanticResourceAttributes.PROCESS_EXECUTABLE_NAME] ===
            '' ||
            processResource[SemanticResourceAttributes.PROCESS_EXECUTABLE_PATH] ===
                '' ||
            processResource[SemanticResourceAttributes.PROCESS_COMMAND] === '' ||
            processResource[SemanticResourceAttributes.PROCESS_COMMAND_LINE] === '' ||
            processResource[SemanticResourceAttributes.PROCESS_RUNTIME_VERSION] === '') {
            diag.debug('ProcessDetector failed: Unable to find required process resources. ');
            return Resource.empty();
        }
        else {
            return new Resource(__assign({}, processResource));
        }
    };
    return ProcessDetectorSync;
}());
export var processDetectorSync = new ProcessDetectorSync();
//# sourceMappingURL=ProcessDetectorSync.js.map